<?php
/**
 * @file
 * Survey Content Types UI
 * For users with admin access
 *  - admin can assign which content type to be used in surveys
 *  - choose how many blank new rows
 *  - configure five stars 
 */

/**
 * Configure Form
 * call back for admin/settings/surveys menu
 */ 
function surveys_admin() {

  drupal_set_title(t('Surveys Settings'));
  
  $form = array();
  
  // Get surveys.configure.inc
  surveys_module_exists(&$form, 'surveys', 'configure');
  
  // Get surveys_points.configure.inc  
  surveys_module_exists(&$form, 'surveys_points', 'configure');

  $form['submit'] = array( '#type' => 'submit', '#value' => t('Save Settings'), );

  return $form;
}

/**
 * Configure Submit
 *
 */
function surveys_admin_submit($form, $form_state) {
  $form_values = $form_state['values'];
  // Saves all configurations on variables
  // otherwise delete these variables associated with the content type
  $modules = array();
  $modules[] = 'surveys';
  
  module_exists('fivestar') ? $modules[] = 'fivestar': '';
  // Surveys Group
  foreach ($form_values['surveys'] as $type) {
    // Add standard settings for each module
    surveys_variable_trigger($type, $modules, $type['type']);
    // Add Survey points to survey types
    if (module_exists('surveys_points') && $type['surveys_points_add'] && $type['surveys_enabled']) {
      variable_set('surveys_points_add_' . $type['type'], $type['surveys_points_add']);
    }
    else {
      variable_del('surveys_points_add_' . $type['type']);
    }
  }
  // Surveys Points Group
  // TODO: Got to make this simplier
  if (module_exists('surveys_points')) {
    $modules = array('surveys_points');
    foreach ($form_values['surveys_points'] as $type) {
      // Add standard settings for each module
      surveys_variable_trigger($type, $modules, $type['type']);
    }
  }
  cache_clear_all();
  menu_rebuild();
}

/**
 * Implementation of theme_surveys_configure()
 * - View in table format
 */
function theme_surveys_admin($form) {
  $output = '';
  $rows = array();
  foreach (element_children($form['surveys']) as $key) {
    $row = array();
    // Strip labels 
    $form['surveys'][$key]['surveys_enabled']['#title'] = '';
    $form['surveys'][$key]['type_name']['#title'] = '';
    $form['surveys'][$key]['surveys_number']['#title'] = '';
 
    $row[] = drupal_render($form['surveys'][$key]['surveys_enabled']);
    $row[] = drupal_render($form['surveys'][$key]['type_name']);
    $row[] = drupal_render($form['surveys'][$key]['surveys_number']);
 
    if (module_exists('fivestar')) {    
      $form['surveys'][$key]['fivestar_enabled']['#title'] = '';
      $form['surveys'][$key]['fivestar_number']['#title'] = '';
      $row[] = drupal_render($form['surveys'][$key]['fivestar_enabled']);
      $row[] = drupal_render($form['surveys'][$key]['fivestar_number']);
    }
    
    if (module_exists('surveys_points')) {    
      $form['surveys'][$key]['surveys_points_add']['#title'] = '';
      $row[] = drupal_render($form['surveys'][$key]['surveys_points_add']);
    }    
    $rows[] = $row;
  }

  // Header
  $header = array('Enable', 'Content Types', 'New Rows');
  if (module_exists('fivestar')) {
    $header[] = 'Enable Fivestar'; 
    $header[] = 'Number of Stars';
  }
  if (module_exists('surveys_points')) {
    $header[] = 'Set Survey Points';
  }
  $form['surveys']['#children'] = theme('table', $header, $rows);
  
  // Surveys Points Fieldset
  if (module_exists('surveys_points')) { 
    $rows = array();   
    foreach (element_children($form['surveys_points']) as $key) {
      $row = array();
      // Strip labels 
      $form['surveys_points'][$key]['surveys_points_enabled']['#title'] = '';
      $form['surveys_points'][$key]['type_name']['#title'] = '';
      $form['surveys_points'][$key]['surveys_points_number']['#title'] = '';
 
      $row[] = drupal_render($form['surveys_points'][$key]['surveys_points_enabled']);
      $row[] = drupal_render($form['surveys_points'][$key]['type_name']);
      $row[] = drupal_render($form['surveys_points'][$key]['surveys_points_number']);

      $rows[] = $row;
    }
    // Header
    $header = array('Enable', 'Content Types', 'New Rows');  
    $form['surveys_points']['#children'] = theme('table', $header, $rows);
  }
  
  $output .= drupal_render($form);
  return $output;
}




