<?php
/**
 * @file
 * Choices UI
 *
 */
 
/**
 * Choices Form
 *
 */ 
function surveys_choices(&$form_state) {
  $node = node_load(arg(1));
  // Get current question
  $select_question = db_query("SELECT qid, question FROM {surveys_questions} WHERE qid = %d", arg(3)); 
  $current_question = db_fetch_object($select_question);
  
  drupal_set_title(t('Edit Choices for "%title"', array('%title' => check_plain($current_question->question))));

  // Get questions for this node type  
  $result = db_query("SELECT sc.cid, sc.nid, sc.qid, sc.choice, sc.enabled, sc.weight, sc.description, sq.qid, sq.question 
                      FROM {surveys_choices} sc JOIN {surveys_questions} sq ON sc.qid = sq.qid 
                      WHERE sc.nid = %d AND sc.qid = %d ORDER BY sc.weight ASC", 
                      arg(1), arg(3)); 
    
  $choices = array();
  // Put categories in an array
  while ($record = db_fetch_object($result)) {
    $record->nid = arg(1);
    $record->qid = arg(3);
    $choices[] = _surveys_choices($record);
  }    

  $form['choices'] = array(
    '#type' => 'fieldset',
    '#title' => t('Add / Edit / Delete your choices.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
  );

  $record = new stdClass();
  $record->nid = arg(1);
  $record->qid = arg(3);
  $record->question = $current_question->question;  
  $rows_blank = variable_get('surveys_number_' . $node->type, 1);  
  surveys_blank_rows(&$choices, $rows_blank, $record, 'choices');

  $form['choices'] += $choices;

  $form['submit'] = array( '#type' => 'submit', '#value' => t('Save choices'), 
  
  );

  return $form;
}

/**
 * Choices Form
 *
 */
function _surveys_choices($record) {
  $form['cid'] = array(
    '#type' => 'hidden',
    '#value' => $record->cid,
  );
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $record->nid,
  );
  $form['qid'] = array(
    '#type' => 'hidden',
    '#value' => $record->qid,
  );
  $form['question'] = array(
    '#type' => 'hidden',
    '#value' => $record->question,
  );
  $form['enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enabled'),
    '#return_value' => 1,
    '#default_value' => (boolean)($record->enabled),
    '#description' => t(''),
  );

  $form['choice'] = array(
    '#type' => 'textfield',
    '#title' => t('Choice'),
    '#return_value' => 1,
    '#default_value' => $record->choice,
    '#size' => 30,
  );

  $form['weight'] = array(
    '#type' => 'select',
    '#title' => t('Weight'),
    '#return_value' => 1,
    '#default_value' => ($record->weight) ? $record->weight: 0,
    '#options' => drupal_map_assoc(range(-50, 50)),
    '#description' => t(''),
  );
  
  $form['description'] = array(
    '#type' => 'textfield',
    '#title' => t('Short Description'),
    '#return_value' => 1,
    '#default_value' => $record->description,
    '#description' => t(''),
    '#size' => 30,
  );
        
  $form['update'] = array(
    '#type' => ($form['cid']['#value']) ? 'checkbox' : 'hidden',
    '#title' => t('Update'),
    '#return_value' => 1,
    '#default_value' => 0,
    '#description' => t(''),
  );
  $form['delete'] = array(
    '#type' => ($form['cid']['#value']) ? 'checkbox' : 'hidden',
    '#title' => t('Delete'),
    '#return_value' => 1,
    '#default_value' => 0,
    '#description' => t(''),
  );
  return $form;
}

/**
 * Choices Submit
 *
 */
function surveys_choices_submit($form, $form_state) {
  $form_values = $form_state['values'];

  foreach ($form_values['choices'] as $choice) {
    if ($choice['cid'] && $choice['update']) {
      // Update an existing choice
      db_query("UPDATE {surveys_choices} SET choice = '%s', enabled = %d, weight = %d, description = '%s' WHERE cid = %d", $choice['choice'], $choice['enabled'], $choice['weight'], $choice['description'], $choice['cid']);
      drupal_set_message(t('A choice for "' . $choice['question'] . '" has been updated.'));
    }
    elseif ($choice['enabled'] && $choice['delete']) {
      // Admin is trying to delete enabled category
      drupal_set_message(t('The choice, "' . $choice['choice'] . '," is enabled, therefore cannot be deleted.'));
    }        
    elseif (!$choice['enabled'] && $choice['delete']) {
      // Delete an existing choice
      db_query("DELETE FROM {surveys_choices} WHERE cid = %d", $choice['cid']);
      drupal_set_message(t('A choice for "' . $choice['question'] . '" has been removed.'));
    }
    elseif (!$choice['cid'] && !empty($choice['choice'])) {
      // Create a new choice
      db_query("INSERT INTO {surveys_choices} (nid, qid, choice, enabled, weight, description) VALUES (%d, %d, '%s', %d, %d, '%s')", $choice['nid'], $choice['qid'],  $choice['choice'], $choice['enabled'], $choice['weight'], $choice['description'] );
      drupal_set_message(t('A choice for "' . $choice['question'] . '" has been added.'));
    }
    else {
      // If no condition is set, nothing should happen
    }
  }
}

/**
 * Implementation of theme_surveys_choices()
 * - View in table format
 *
 */
function theme_surveys_choices($form) {
//dsm($form);
  $rows = array();
  $output = '';
  foreach (element_children($form['choices']) as $key) {
    $row = array();

    // Strip labels 
    $form['choices'][$key]['enabled']['#title'] = '';
    $form['choices'][$key]['update']['#title'] = '';
    $form['choices'][$key]['choice']['#title'] = '';
    $form['choices'][$key]['description']['#title'] = '';
    $form['choices'][$key]['weight']['#title'] = '';
    $form['choices'][$key]['delete']['#title'] = '';
        
    $row[] = drupal_render($form['choices'][$key]['enabled']);
    $row[] = drupal_render($form['choices'][$key]['update']);
    $row[] = drupal_render($form['choices'][$key]['choice']);
    $row[] = drupal_render($form['choices'][$key]['description']);
    $row[] = drupal_render($form['choices'][$key]['weight']);
    $row[] = drupal_render($form['choices'][$key]['delete']);
    $rows[] = $row;
  }

  $header = array('Enabled', 'Update / Save', 'Choices', 'Short Description', 'Weight', 'Delete');

  // Header
  $form['choices']['#children'] = theme('table', $header, $rows);

  $output .= drupal_render($form);
  return $output;
}






