<?php
/**
 * @file
 * Survey Content Types UI
 * For users with admin access
 *  - admin can assign which content type to be used in surveys
 *  - choose how many blank new rows
 *  - configure five stars 
 */

/**
 * Configure Form
 * call back for admin/settings/surveys menu
 */ 
function surveys_configure($form) {

  $configure = array();

  // Get default values from variable table
  // All node types have 0 for not using surveys and 1 for using surveys
  foreach (node_get_types() as $type => $info) {
    $configure[] = _surveys_configure($type, $info);
  }
  
  $form['surveys'] = array(
    '#type' => 'fieldset',
    '#title' => t('Survey Types'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
    '#description' => t('The survey forms will be attached to the following content types if checked.'),
  );

  $form['surveys'] += $configure;

  return $form;
}

/**
 * Configure form
 *
 */
function _surveys_configure($type, $info) {
  $form['surveys_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t(''),
    '#default_value' => variable_get('surveys_enabled_'. $type, 0),
  ); 
  $form['type'] = array(
    '#type' => 'hidden',
    '#default_value' => $type,
  );
  $form['type_name'] = array(
    '#type' => 'markup',
    '#value' => $info->name,
  );
  if (variable_get('surveys_enabled_' . $type, '')) {
    $form['surveys_number'] = array(
      '#type' => 'select',
      '#default_value' => variable_get('surveys_number_' . $type, 1),
      '#options' => drupal_map_assoc(range(1, 10)),
    ); 
    if (module_exists('fivestar')) {
      $form['fivestar_enabled'] = array(
        '#type' => 'checkbox',
        '#title' => t('Use Fivestar for surveys'),
        '#default_value' => variable_get('surveys_fivestar_enabled_' . $type, 0),
      );
      $form['fivestar_number'] = array(
        '#type' => 'select',
        '#title' => t('Number of stars'),
        '#options' => drupal_map_assoc(range(1, 10)),
        '#default_value' => variable_get('surveys_fivestar_number_' . $type, 5),
      );
    }
    if (module_exists('surveys_points')) {
      $form['surveys_points_add'] = array(
        '#type' => 'checkbox',
        '#title' => t('Add User Points'),
        '#default_value' => variable_get('surveys_points_add_' . $type, 0),
      );
    }    
  }
  else {
    $form['surveys_number'] = array(
      '#type' => 'hidden',
      '#default_value' => 1,
    );
    if (module_exists('fivestar')) {
      $form['fivestar_enabled'] = array(
        '#type' => 'hidden',
        '#default_value' => 0,
      );
      $form['fivestar_number'] = array(
        '#type' => 'hidden',
        '#default_value' => 0,
      );
    }
    if (module_exists('surveys_points')) {
      $form['surveys_points_add'] = array(
        '#type' => 'hidden',
        '#default_value' => 0,
      );
    }          
  }

  return $form; 
}
