<?php
/**
 * @file
 * User Survey UI Form
 *
 */

/**
 * Menu callback for /node/%/manage-survey/[title]
 *
 */
function surveys_form(&$form_state, $node) {

  drupal_add_css(drupal_get_path('module', 'surveys') . '/css/surveys.css');
  drupal_add_js(drupal_get_path('module', 'surveys') . '/js/surveys.js');
 
  // Get categories for this node type
  $categories = surveys_categories_get($node->type);
  $form['thisnode'] = array(
    '#type' => 'hidden',
    '#value' => $node->nid,
  );
  // Get choices for this node
  $choices = surveys_choices_get($node->nid);
 
  //Get questions for this node 
  $result = db_query("SELECT sq.qid, sq.question, sq.description AS questdesc, sq.cid, sq.multiple, sq.enabled AS enabled1, sq.node_type, 
                             sc.category, sc.description AS catdesc, 
                             sm.mid, sm.enabled AS enabled2, sm.archive, sm.chrate, sm.comment, sm.weight
                      FROM {surveys_questions} sq 
                      LEFT JOIN {surveys_manage} sm ON sq.qid = sm.qid 
                      LEFT JOIN {surveys_categories} sc ON sq.cid = sc.cid 
                      WHERE sq.node_type = '%s' AND sm.uid = %d AND sm.nid = %d AND sq.qid IN (SELECT qid FROM {surveys_manage} WHERE nid = %d AND uid = %d AND archive = 0 AND enabled = 1)
                      ORDER BY sc.category, sm.weight, sq.question ASC", 
                      $node->type, $node->uid, $node->nid, $node->nid, $node->uid);  
     print $node->nid;
  $questions = array();                                                  
  // Put choices on each question
  while ($record = db_fetch_object($result)) {
    $record->nid = $node->nid;
    $record->node_type = $node->type;
    $record->node_title = $node->title;
    $record->choices = $choices;
    ($record->enabled1) ? $questions[] = _surveys_form($record) : '';
  } 

  $category_group = surveys_categories_group($categories, $questions);

  // Don't show any fieldset if there are no questions
  if (!empty($questions[0])) {
    $form['questions'] = array(
      '#type' => 'fieldset',
      '#title' => t('Questions for ' . $node->title),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#tree' => TRUE,
    );

    $form['questions'] += $category_group;

    $form['submit'] = array( '#type' => 'submit', '#value' => t('Submit'), );

    return $form;
  } 
  else {
    // Show a message instead
    drupal_set_message(t('This survey is inactive or closed.'));
  } 
}

/**
 * User Form
 *
 */
function _surveys_form($record) {
  //options
  for ($i = 1; $i < 11; $i++ ) {
    $options[$i*10] = $i; 
  }
  
  $form['qid'] = array(
    '#type' => 'hidden',
    '#value' => $record->qid,
  );
  $form['mid'] = array(
    '#type' => 'hidden',
    '#value' => $record->mid,
  ); 
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $record->nid,
  ); 
  $form['node_type'] = array(
    '#type' => 'hidden',
    '#value' => $record->node_type,
  );   
  $form['node_title'] = array(
    '#type' => 'hidden',
    '#value' => $record->node_title,
  );   
  $form['question_display'] = array(
    '#type' => 'markup',
    '#prefix' => '',
    '#suffix' => '',
    '#value' => '<tr class="odd"><td colspan="3"><h3>' . $record->question . '</h3><p>' . $record->questdesc . '</p></td></tr>',
  );

  $form['question'] = array(
    '#type' => 'hidden',
    '#value' => $record->question,
  );
  $form['category'] = array(
    '#type' => 'hidden',
    '#return_value' => 1,
    '#default_value' => $record->cid,
    '#description' => $record->catdesc,
  );  
  $form['choices'] = array(
    '#type' => 'fieldset',
    '#attributes' => array('id' => 'question-' . $record->qid),
    '#title' => t(''),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
  ); 
  $form['chrate'] = array(
    '#type' => 'hidden',
    '#value' => $record->chrate,
  ); 
  if (!$record->chrate) {
    $choices_only = $record->choices[$record->qid];
    foreach (element_children($choices_only) AS $chkey) {
      $choices[$chkey] = $choices_only[$chkey]['choice'];
    } 
    $form['choices']['rating'] = array(
      //'#type' => 'select',
      '#type' => 'radios',
      '#title' => t(''),
      '#return_value' => 1,
      '#default_value' => 50,
      '#prefix' => '<div class="surveys-ratings">',
      '#suffix' => '<div class="clearfix"></div></div>',

      '#options' => $options,
      '#description' => t(''),
    );
    if (variable_get('surveys_fivestar_enabled_' . $record->node_type, '')) {
      $form['choices']['rating']['#type'] = 'fivestar';
      $form['choices']['rating']['#stars'] = variable_get('surveys_fivestar_number_' . $record->node_type, 5);
    } 
    if ($record->multiple && !empty($record->choices[$record->qid])) {
      $form['choices']['choice'] = array(
        '#type' => 'radios',
        '#title' => t(''),
        '#return_value' => 1,
        '#options' => ($record->multiple) ? $choices : '',
      );
    }
    else {
      $form['choices']['choice'] = array(
        '#type' => 'markup',
        '#title' => t('Choices'),
        '#return_value' => 1,
        '#value' => 'None'
      );
    }
  } 
  else { 
    $choices = $record->choices[$record->qid];
    $form['choices'] = !empty($choices) ? surveys_choices_ratings($form['choices'], $choices, $options, $record): '';
  }
  if ($record->comment) {
    $form['commentset'] = array(
      '#type' => 'fieldset',
      '#title' => t('Comment'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['commentset']['comment'] = array(
      '#type' => 'textarea',
      '#title' => t(''),
      '#return_value' => 1,
      '#default_value' => '',
      '#row' => 2,
      '#description' => t('Add you comments / suggestions.'),
    );
  }
  else {
    $form['comment'] = array(
      '#type' => 'markup',
      '#title' => t('Choices'),
      '#return_value' => 1,
      '#value' => 'Commenting is disabled.'
    );
  }      
  
  return $form;
}

/**
 * Choices with ratings
 *
 */
function surveys_choices_ratings($form, $choices, $options, $record) {
  $output = '';
  $form[0]['choice'] = array(
    '#type' => 'checkbox',
    '#title' => t('Choice'),
    '#return_value' => 1,
    '#attributes' => array('class' => 'choice-off'),
    '#prefix' => '<div class="surveys-choice surveys-choice-none">',
    '#suffix' => '</div>',    
    '#default_value' => 0,
    '#title' => t('None'),
  ); 
  $form[0]['ratings'] = array(
    '#type' => 'hidden',
    '#title' => t(''),
    '#return_value' => 1,
    '#value' => 0,
    '#prefix' => '<div class="surveys-ratings surveys-ratings-none">',
    '#suffix' => '<div class="clearfix"></div></div>',
    '#options' => $options,
    '#description' => t(''),
  ); 
  foreach ($choices AS $key => $choice) {
    $form[$key] = _surveys_choices_ratings($choice['choice'], $options, $record); 
  } 
  return $form;
}

/**
 * Choices with ratings
 *
 */
function _surveys_choices_ratings($choice, $options, $record) {


  $form['choice_name'] = array(
    '#type' => 'hidden',
    '#return_value' => 1,    
    '#default_value' => $choice,
  ); 
  $form['choice'] = array(
    '#type' => 'checkbox',
    '#title' => t('Choice'),
    '#return_value' => 1,
    '#prefix' => '<div class="surveys-choice">',
    '#suffix' => '</div>',    
    '#default_value' => 0,
    '#title' => $choice,
  );
  $form['ratings'] = array(
    '#type' => 'radios',
    '#title' => t(''),
    '#return_value' => 1,
    '#default_value' => 50,
    '#prefix' => '<div class="surveys-ratings">',
    '#suffix' => '<div class="clearfix"></div></div>',
    '#options' => $options,
    '#description' => t(''),
  ); 
  if (variable_get('surveys_fivestar_enabled_' . $record->node_type, '')) {
    $form['ratings']['#type'] = 'fivestar';
    $form['ratings']['#stars'] = variable_get('surveys_fivestar_number_' . $record->node_type, 5);
  } 

  return $form;
}

/**
 * Form Submit
 *
 */
function surveys_form_submit($form, $form_state) {
  global $user;
  $votes = array();
  $form_values = $form_state['values'];
  foreach ($form_values['questions'] as $category) {
    foreach ($category as $myrating) {
      if ($myrating['rid'] && $myrating['update']) {
        // Update an existing ratings
        // TODO
        // Users cannot modify surveys yet
        $myrating['commentset']['comment'] = check_plain($myrating['commentset']['comment']);
        db_query("UPDATE {surveys_ratings} SET comment = '%s' WHERE rid = %d", $myrating['commentset']['comment'], $myrating['rid']);
        drupal_set_message(t('The ratings and comments on "(' . $myrating['question'] . ')" has been updated.'));
      }
      elseif (!$myrating['rid']) {
        $comment_include = '';
        // If choices are rated tag gets the choice instead of the question
        if ($myrating['chrate']) {
          // The none choice
          if ($myrating['choices'][0]['choice'] == 0) {
            foreach (element_children($myrating['choices']) AS $chkey) {
              // If the choice is rated
              if ($myrating['choices'][$chkey]['choice']) {
                $comment_include .= "\"" . $myrating['choices'][$chkey]['choice_name'] . "\", ";
                $votes[] = array('value' => $myrating['choices'][$chkey]['ratings'], 'tag' => $myrating['choices'][$chkey]['choice_name'], 'content_type' => 'node', 'content_id' => $myrating['nid']);
              }
            }
          } 
          else {
            $comment_include = 'None'; // The user didn't choose anthing
          }
        } 
        else {
          $surveys_choices = surveys_choices_get($myrating['nid']);
          $comment_include .= "\"" . $surveys_choices[$myrating['qid']][$myrating['choices']['choice']]['choice'] . "\", ";
          // Use votingapi to save the ratings
          $votes[] = array('value' => $myrating['choices']['rating'], 'tag' => $myrating['question'], 'content_type' => 'node', 'content_id' => $myrating['nid']);
        }
        // Save ratings and comments
        $myrating['commentset']['comment'] = check_plain($myrating['commentset']['comment']);
        db_query("INSERT INTO {surveys_ratings} (nid, uid, qid, comment) VALUES (%d, %d, %d, '%s')", $myrating['nid'], $user->uid, $myrating['qid'], $comment_include . $myrating['commentset']['comment']);
      }
      else {
        // If no condition is set, nothing should happen
      }
      $title = $myrating['node_title'];
    }
    
  }

  // Surveys node ID
  $thisnode = $form_values['thisnode'];
    
  if (module_exists('surveys_points')) {
    // Adds points to associated nodes to this survey
    surveys_points_add_points($thisnode, $user->uid);
  }
  
  // votingapi_set_vote('rating', 'question', 'content_typ', 'content_id');
  votingapi_set_votes($votes);
  drupal_set_message(t('Your ratings and comments on "' . $title . '" has been saved.'));
}

/**
 * Implementation of theme_surveys_form()
 * - View in table format
 */
function theme_surveys_form($form) {
  $output = '';
  foreach (element_children($form['questions']) as $cat) {
    foreach (element_children($form['questions'][$cat]) as $key) {
      if ($form['questions'][$cat][$key]['chrate']['#value'] == 1) {
        // if choices are rated individually
        $crows = array();
        foreach (element_children($form['questions'][$cat][$key]['choices']) as $chkey) {
          $crow = array(); 
          $crow[] = drupal_render($form['questions'][$cat][$key]['choices'][$chkey]['choice']);
          $crow[] = drupal_render($form['questions'][$cat][$key]['choices'][$chkey]['ratings']);
          $crows[] = $crow;
        }
        $header = array('Choices', 'Ratings');
        $form['questions'][$cat][$key]['choices']['#children'] = theme('table', $header, $crows);
      }
      else {
        // if there are choices but not rated individually
        $crows = array();
        $crow = array();
        $crow[] = drupal_render($form['questions'][$cat][$key]['choices']['choice']);
        $crow[] = drupal_render($form['questions'][$cat][$key]['choices']['rating']);
        $crows[] = $crow;
        $header = array('Choices', 'Ratings');
        $form['questions'][$cat][$key]['choices']['#children'] = theme('table', $header, $crows);
      }
    }
  }
  $output = drupal_render($form);
  return $output;
}




