<?php
/**
 * @file
 * Manage Survey UI
 *
 */
 
/**
 * Menu callback for /node/%/manage-survey
 *
 */ 
function surveys_manage(&$form_state) {
  global $user;
  
  $node = node_load(arg(1));
  
  drupal_set_title(t('Manage Questions for %title', array('%title' => $node->title)));
  
  //This is a quide to these questions for this survey.
  $user_help = variable_get('surveys_help_'. $node->type, '');
  
  if (trim($user_help)) {
    $form[$node->type] = array(
      '#type' => 'fieldset',
      '#title' => t('Survey Owner Help Guide'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#description' => variable_get('surveys_help_'. $node->type, ''),
    );
  }
   
 $form['questions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configure your survey questions.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
  );

  // We need to add questions to the surveys manage table with new question from the surveys_questions  
  $questions_available_result = db_query(
                     "SELECT sq.qid, sq.node_type
                      FROM {surveys_questions} sq 
                      WHERE sq.node_type = '%s' AND sq.qid NOT IN (SELECT sm.qid FROM {surveys_manage} sm WHERE sm.nid = %d)", 
                      $node->type, $node->nid);  
  
  while ($questions_available = db_fetch_object($questions_available_result)) {
    db_query("INSERT INTO {surveys_manage} (nid, uid, qid) VALUES (%d, %d, %d)", $node->nid, $user->uid, $questions_available->qid);
  } 
  
  $categories = surveys_categories_get($node->type);
            
  //Get questions for this node type  
  $result = db_query("SELECT sq.qid, sq.question, sq.description AS questdesc, sq.cid, sq.multiple, sq.enabled AS enabled1, sq.node_type,  
                             sc.category, sc.description AS catdesc, 
                             sm.mid, sm.nid, sm.enabled AS enabled2, sm.archive, sm.chrate, sm.comment, sm.weight
                      FROM {surveys_questions} sq 
                      LEFT JOIN {surveys_manage} sm ON sq.qid = sm.qid 
                      LEFT JOIN {surveys_categories} sc ON sq.cid = sc.cid 
                      WHERE sq.node_type = '%s' AND sm.nid = %d
                      ORDER BY sc.category, sm.weight, sq.question DESC", 
                      $node->type, $node->nid);  


  $questions = array();                                                  
  // Put categories in an array
  while ($record = db_fetch_object($result)) {
    $record->uid = $node->uid;
    ($record->enabled1 && !$record->archive) ? $questions[] = _surveys_manage($record) : '';
  } 
  $category_group = surveys_categories_group($categories, $questions);
  
  $form['questions'] += $category_group;
  
  // Make sure that only the owner can edit his own form
  if ($user->uid == $node->uid) {
    $form['submit'] = array( '#type' => 'submit', '#value' => t('Save my survey'), '#disabled' => empty($questions) ? TRUE : FALSE, ); 
  }
  else {
    drupal_set_message(t('You are not the author of this content, therefore you cannot edit its survey content.'));
  }  
  return $form;
}

/**
 * Manage Form
 *
 */
function _surveys_manage($record) {
  $form['qid'] = array(
    '#type' => 'hidden',
    '#value' => $record->qid,
  );
  $form['mid'] = array(
    '#type' => 'hidden',
    '#value' => $record->mid,
  ); 
  $form['uid'] = array(
    '#type' => 'hidden',
    '#value' => $record->uid,
  ); 
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $record->nid,
  ); 
  $form['enabled2'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enabled'),
    '#return_value' => 1,
    '#default_value' => (boolean)($record->enabled2),
    '#description' => t(''),
  );
  $form['update'] = array(
    '#type' => 'checkbox',
    '#title' => t('Update'),
    '#return_value' => 1,
    '#default_value' => 0,
    '#description' => t(''),
  );  
  $form['category'] = array(
    '#type' => 'hidden',
    '#return_value' => 1,
    '#default_value' => $record->cid,
    '#description' => $record->catdesc,
  );      
  $form['question_display'] = array(
    '#type' => 'markup',
    '#value' => '<h3>' . $record->question . '</h3><p>' . $record->questdesc . '</p>',
  );
  $form['question'] = array(
    '#type' => 'hidden',
    '#value' => $record->question,
  );
  $form['choices'] = array(
    '#type' => 'markup',
    '#title' => t('Choices'),
    '#return_value' => 0,
    '#value' => ($record->multiple) ? t('<a href="' . base_path() . 'node/' . $record->nid . '/manage-survey/' . $record->qid . '/choices">Edit Choices</a>') : 'N/A',
  );
  $form['chrate'] = array(
    '#type' => ($form['mid']['#value'] && $record->multiple) ? 'checkbox' : 'hidden',
    '#title' => t('Comment'),
    '#return_value' => 1,
    '#default_value' => (boolean)($record->chrate),
    '#description' => t(''),
  ); 
  $form['comment'] = array(
    '#type' => ($form['mid']['#value']) ? 'checkbox' : 'hidden',
    '#title' => t('Comment'),
    '#return_value' => 1,
    '#default_value' => (boolean)($record->comment),
    '#description' => t(''),
  );
  if ($form['mid']['#value']) {
    $form['weight'] = array(
      '#type' => 'select',
      '#title' => t('Weight'),
      '#return_value' => 1,
      '#default_value' => ($record->weight) ? $record->weight: 0,
      '#options' => drupal_map_assoc(range(-50, 50)),
      '#description' => t(''),
    );
  }
  else {
    $form['weight'] = array(
      '#type' => 'hidden',
      '#default_value' => $record->weight,
    ); 
  }
  $form['remove'] = array(
    '#type' => 'checkbox',
    '#title' => t('Archive'),
    '#return_value' => 1,
    '#default_value' => 0,
    '#description' => t(''),
  ); 
  return $form;
}

/**
 * Manage Submit
 *
 */
function surveys_manage_submit($form, $form_state) {
  global $user;
  $node = node_load(arg(1));
  $form_values = $form_state['values'];

  foreach ($form_values['questions'] as $category) {
    foreach ($category as $manage) {
      if ($manage['update'] && !$manage['remove']) {
        // Update a question
        db_query("UPDATE {surveys_manage} SET enabled = %d, chrate = %d, comment = %d, weight = %d WHERE mid = %d", $manage['enabled2'], $manage['chrate'], $manage['comment'], $manage['weight'], $manage['mid']);
        drupal_set_message(t('The question (' . $manage['question'] . ') has been updated.'));
      }
      elseif ($manage['remove'] && $manage['update']) {
        // Archives old a question, Remove a question from management
        db_query("UPDATE {surveys_manage} SET archive = 1 WHERE nid = %d AND qid = %d", $node->nid, $manage['qid']);
        drupal_set_message(t('The question (' . $manage['question'] . ') has been archived.'));
      }  
      else {
        // If no condition is set, nothing should happen
      }
    }
  }
}

/**
 * Implementation of theme_surveys_manage()
 * - View in table format
 */
function theme_surveys_manage($form) {
  $output = '';
  foreach (element_children($form['questions']) as $cat) {
    $rows = array();
    foreach (element_children($form['questions'][$cat]) as $key) {
      $row = array();
      // Strip labels 
      $form['questions'][$cat][$key]['enabled2']['#title'] = '';
      $form['questions'][$cat][$key]['update']['#title'] = '';
      $form['questions'][$cat][$key]['question_display']['#title'] = '';
      $form['questions'][$cat][$key]['choices']['#title'] = '';
      $form['questions'][$cat][$key]['chrate']['#title'] = '';
      $form['questions'][$cat][$key]['comment']['#title'] = '';
      $form['questions'][$cat][$key]['weight']['#title'] = '';
      $form['questions'][$cat][$key]['remove']['#title'] = '';
      $row[] = drupal_render($form['questions'][$cat][$key]['enabled2']);
      $row[] = drupal_render($form['questions'][$cat][$key]['update']);
      $row[] = drupal_render($form['questions'][$cat][$key]['question_display']);
      $row[] = drupal_render($form['questions'][$cat][$key]['choices']);
      $row[] = drupal_render($form['questions'][$cat][$key]['chrate']);
      $row[] = drupal_render($form['questions'][$cat][$key]['comment']);
      $row[] = drupal_render($form['questions'][$cat][$key]['weight']);
      $row[] = drupal_render($form['questions'][$cat][$key]['remove']);
      $rows[] = $row;
    }

    $header = array('Enabled', 'Update / Save', 'Questions', 'Choices', 'Rate Choices', 'Enable Comment', 'Weight', 'Archive');

    // Header
    $form['questions'][$cat][$key]['#children'] = theme('table', $header, $rows);
  }
  $output .= drupal_render($form);
  return $output;
}






