<?php
/**
 * @file
 * Surveys Utilities
 *
 */
 
/**
 * Check if user has rated this node already
 *
 */
function surveys_form_check($uid, $nid) {
  global $user;
  
  if ($user->uid == 0) {
    // Check IP Address from votingapi table
    $anonymous = db_query("SELECT content_id, vote_source FROM {votingapi_vote} WHERE content_id = %d", $nid); 
    $anonymous_record = db_fetch_object($anonymous);
    
    $ip = $anonymous_record->vote_source;
    
    if ($ip == ip_address()) {
      return TRUE; 
    }
    else {
      return FALSE; 
    }
  } 
  else {
    // Check if user has rated this survey already
    $ratings_result = db_query("SELECT rid, nid, uid, qid FROM {surveys_ratings} WHERE uid = %d AND nid = %d ORDER BY qid ASC", $uid, $nid);
    // Put ratings in an array
    $ratings = array();
    while ($ratings_record = db_fetch_object($ratings_result)) {
      $ratings[$ratings_record->nid][$ratings_record->qid] = $ratings_record->rid;
    }  
  
    //print_r($ratings);
    if (!empty($ratings)) { 
      return TRUE; 
    } 
    else { 
      return FALSE; 
    }
  }
}

/**
 * Get categories of questions
 *
 */
function surveys_categories_get($type) {
  // Get categories for this node type
  $cat_result = db_query("SELECT cid, node_type, category FROM {surveys_categories} WHERE node_type='%s' AND enabled = 1 ORDER BY category ASC", $type);
  $categories[0] = 'General';
  // Put categories in an array
  while ($cat_record = db_fetch_object($cat_result)) {
    $categories[$cat_record->cid] = $cat_record->category;
  }  
  return $categories;
}  

/**
 * Get categories of questions
 *
 */
function surveys_choices_get($nid) {
  // Get choices for this node
  $choices_result = db_query("SELECT cid, nid, qid, choice, enabled, weight, description FROM {surveys_choices} WHERE nid = %d AND enabled = 1 ORDER BY weight ASC", $nid);

  // Put choices in an array
  while ($choices_record = db_fetch_object($choices_result)) {
    $choices[$choices_record->qid][$choices_record->cid]['choice'] = ($choices_record->description ) ? $choices_record->choice . ' (' . $choices_record->description . ')' : $choices_record->choice;
  }  
  return $choices;
}

/**
 * Put questions inside category fieldsets
 *
 */
function surveys_categories_group($categories = NULL, $questions = NULL) {
  // Put questions inside the categories
  $category_group = array();
  foreach ( $questions as $qkey => $question) {
    $cat_id = $question['category']['#default_value'];
    $cat_name = $categories[$cat_id];  
    $cat_desc = $question['category']['#description'];
    $category_group[$cat_name][$qkey] = $question;
    $category_group[$cat_name] += array( '#type' => 'fieldset', '#title' => t($cat_name), '#collapsible' => TRUE, '#collapsed' => FALSE, '#tree' => TRUE, '#description' => $cat_desc, );
  }
  return $category_group;
}

/**
 * Add blank rows
 *
 */
function surveys_blank_rows($query = NULL, $times = 1, $record = NULL, $form_type = NULL) {
  // add a number of blank rows
  ($form_type == 'questions') ? $query = array(): '';
  $form_process = '_surveys_' . $form_type;
  for ($i = 0; $i < $times; $i++) {
    $query[] = $form_process($record);  
  }
  return $query;
}

/**
 * Surveys Other Modules Integrator
 *
 */
function surveys_module_exists($form = array(), $module = NULL, $param = NULL) {
  if (module_exists($module)) {
    require_once(drupal_get_path('module', $module) . '/inc/' . $module . '.configure.inc');
    $function = $module . '_' . $param;
    return $function(&$form);  
  }
}

/**
 * Triggers creation and deletion of surveys variables
 * - if enabled
 * - number value
 */
function surveys_variable_trigger($form = array(), $modules = array(), $type = NULL) {
  foreach ($modules as $mkey => $module_name) {
    // Check if it starts with surveys
    (substr($module_name, 0, 7) != 'surveys') ? $var_name = 'surveys_' . $module_name: $var_name = $module_name;

    if ($form[$module_name . '_enabled']) {
      variable_set($var_name . '_enabled_' . $type, $form[$module_name . '_enabled']);
      variable_set($var_name . '_number_' . $type, $form[$module_name . '_number']);
    }
    else {
      variable_del($var_name . '_enabled_' . $type);
      variable_del($var_name . '_number_' . $type);
    }
  }
}

 
